@@ -53,6 +53,8 @@ ClutterActor* jammo_track_view_new(JammoEditingTrack* track, guint n_slots, guin
 void jammo_track_view_add_jammo_sample_button(JammoTrackView* track_view, JammoSampleButton* sample_button, guint slot) {
 	TangleWidget* widget;
 
+	jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button), slot * track_view->priv->slot_duration);
+
 	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_view)));
 
 	clutter_actor_set_x(CLUTTER_ACTOR(sample_button), slot * track_view->priv->real_slot_size);
@@ -449,10 +451,8 @@ static void on_actor_added(TangleWidget* widget, ClutterActor* actor, gpointer u
 	//If user makes first dragging, not clicking, we do not want hear click-message anymore
 	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_click_fi.ogg");
 	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_drag_fi.ogg");
-	if (!jammo_sample_get_editing_track(sample)) {
-		jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button),
-	                        	       clutter_actor_get_x(actor) / track_view->priv->real_slot_size * track_view->priv->slot_duration);
-	}
+
+	g_assert(jammo_sample_get_editing_track(sample));
 }
 
 static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
